@@ -7,15 +7,16 @@ print STDERR "Processing sample 1-3\n";
     [    5,   12,   24,   33,   19,    8,    6,    15,    21],
     [    1,    2,    5,    6,    3,  1.5,    1,     3,     4]
 );
-$my_graph = new GIFgraph::bars( );
+$my_graph = new GIFgraph::bars();
 
-$my_graph->set( 'x_label' => 'X Label',
-                'y_label' => 'Y label',
-                'title' => 'Bars on top of each other',
-                'y_max_value' => 40,
-                'y_tick_number' => 8,
-                'y_label_skip' => 2,
-                'overwrite' => 1 );
+$my_graph->set( 
+	'x_label' => 'X Label',
+	'y_label' => 'Y label',
+	'title' => 'Bars in front of each other',
+	'y_tick_number' => 8,
+	'y_label_skip' => 2,
+	'overwrite' => 1 
+);
 
 $my_graph->plot_to_gif( "sample13.gif", \@data );
 
