@@ -5,7 +5,7 @@ print STDERR "Processing sample 3-1\n";
 @data = ( 
     ["1st","2nd","3rd","4th","5th","6th","7th", "8th", "9th"],
     [    5,   12,   24,   33,   19,    8,    6,    15,    21],
-    [    1,    2,    5,    6,    3,  1.5,    undef,     3,     4]
+    [    1,    2,    5,    6,    3,  1.5,    undef,     3,     4],
 );
 
 $my_graph = new GIFgraph::points();
