@@ -10,9 +10,12 @@ print STDERR "Processing sample 9-1\n";
 $my_graph = new GIFgraph::pie( 250, 200 );
 #$my_graph = new GIFgraph::pie( );
 
-$my_graph->set( 'title' => 'A Pie Chart',
-                'label' => 'Label',
-                'axislabelclr' => 'black' );
+$my_graph->set( 
+	'title' => 'A Pie Chart',
+	'label' => 'Label',
+	'axislabelclr' => 'black',
+	'pie_height' => 36,
+);
 
 $my_graph->plot_to_gif( "sample91.gif", \@data );
 
